==> xl-react-components-0.18.103.tgz: package/app/pages/widget-page/widget-patch-test-editor/wiget-patch-test-editor.js <==
import R from 'ramda';
import React from 'react';
import PropTypes from 'prop-types';
import {XlReactWidgetPatchEditor}
    from '../../../xl-react-widget/xl-react-widget-patch-editor/xl-react-widget-patch-editor';
import {splitLines} from '../../../utils/split-lines';
import {localeMessages} from '../../../services/locale-service';

const WidgetPatchTestEditor = (props) => {
    const updateField = (nameValueMap) => {
        const {currentState, modelName, updateState} = props;
        updateState(modelName, {
            ...currentState[modelName],
            ...nameValueMap
        });
    };

    const getLineNumber = (selectedLines) => R.pipe(
        R.head,
        R.curry(parseInt)(R.__, 10)
    )(selectedLines) - 1;

    const selectAction = (action) => updateField({selectedAction: action});

    const handlePushPatchChange = (lastPushedPatch) => updateField({
        lastPushedPatch,
        pristine: true
    });

    const getSelectedPath =
        R.pipe(
            R.head,
            R.curry(parseInt)(R.__, 10),
            R.cond([
                [R.gte(3), R.always('/')],
                [R.gte(4), R.always('/metadata')],
                [R.gte(5), R.always('/')],
                [R.gte(6), R.always('/spec')],
                [R.gte(8), R.always('/spec/volumes[0]')],
                [R.gte(9), R.always('/spec')],
                [R.gte(13), R.always('/spec/containers[0]')],
                [R.gte(16), R.always('/spec/containers[0]/volumeMounts')],
                [R.gte(18), R.always('/spec/containers[0]/name')],
                [R.gte(20), R.always('/spec/containers[0]/name/port')],
                [R.gte(23), R.always('/spec/containers[0]/name/volumeMounts')],
                [R.T, R.always('')]
            ]));

    const onLineSelected = (selectedLines) => {
        const {
            model: {
                model,
                selectedAction: originalSelectedAction,
                selectedLines: originalSelectedLines
            }
        } = props;
        const editableSection = R.pipe(
            splitLines,
            R.nth(getLineNumber(selectedLines))
        )(model);
        const selectedAction = !R.equals(selectedLines, originalSelectedLines) ? 'replace' : originalSelectedAction;
        const selectedPath = getSelectedPath(selectedLines);
        updateField({
            editableSection,
            selectedAction,
            selectedLines,
            selectedPath
        });
    };

    const onModelChange = (editableSection) => updateField({
        editableSection,
        pristine: false
    });

    const onModifyingPatch = () => selectAction('replace');

    const onRemovingPatch = () => selectAction('remove');

    const {
        model: {
            editableSection,
            filePath,
            fileType,
            model,
            pristine,
            selectedAction,
            selectedLines,
            selectedPath
        }
    } = props;

    return <XlReactWidgetPatchEditor
        description={localeMessages.patchEditorDescription}
        editableSection={editableSection}
        filePath={filePath}
        handleEditableSelectionChange={onModelChange}
        handleLineSelected={onLineSelected}
        handleModifyingPatch={onModifyingPatch}
        handleRemovingPatch={onRemovingPatch}
        model={model}
        onPushPatchChange={handlePushPatchChange}
        pristine={pristine}
        selectedAction={selectedAction}
        selectedLines={selectedLines}
        selectedPath={selectedPath}
        type={fileType}
    />;
};

WidgetPatchTestEditor.propTypes = {
    currentState: PropTypes.object,
    model: PropTypes.shape({
        editableSection: PropTypes.string.isRequired,
        filePath: PropTypes.string.isRequired,
        fileType: PropTypes.string.isRequired,
        model: PropTypes.string.isRequired,
        pristine: PropTypes.bool.isRequired,
        selectedAction: PropTypes.string.isRequired,
        selectedLines: PropTypes.arrayOf(PropTypes.string).isRequired,
        selectedPath: PropTypes.string.isRequired
    }),
    modelName: PropTypes.string,
    updateState: PropTypes.func
};

export default React.memo(WidgetPatchTestEditor);

==> xl-react-components-0.21.12.tgz: package/app/pages/widget-page/widget-patch-test-editor/wiget-patch-test-editor.js <==
import R from 'ramda';
import React from 'react';
import PropTypes from 'prop-types';
import {XlReactWidgetPatchEditor}
    from '../../../xl-react-widget/xl-react-widget-patch-editor/xl-react-widget-patch-editor';
import {splitLines} from '../../../utils/split-lines';
import {localeMessages} from '../../../services/locale-service';

const WidgetPatchTestEditor = (props) => {
    const updateField = (nameValueMap) => {
        const {modelName, updateState} = props;
        updateState(modelName, {componentProps: {...nameValueMap}});
    };

    const getLineNumber = (selectedLines) => R.pipe(
        R.head,
        R.curry(parseInt)(R.__, 10)
    )(selectedLines) - 1;

    const selectAction = (action) => updateField({selectedAction: action});

    const handlePushPatchChange = (lastPushedPatch) => updateField({
        lastPushedPatch,
        pristine: true
    });

    const getSelectedPath =
        R.pipe(
            R.head,
            R.curry(parseInt)(R.__, 10),
            R.cond([
                [R.gte(3), R.always('/')],
                [R.gte(4), R.always('/metadata')],
                [R.gte(5), R.always('/')],
                [R.gte(6), R.always('/spec')],
                [R.gte(8), R.always('/spec/volumes[0]')],
                [R.gte(9), R.always('/spec')],
                [R.gte(13), R.always('/spec/containers[0]')],
                [R.gte(16), R.always('/spec/containers[0]/volumeMounts')],
                [R.gte(18), R.always('/spec/containers[0]/name')],
                [R.gte(20), R.always('/spec/containers[0]/name/port')],
                [R.gte(23), R.always('/spec/containers[0]/name/volumeMounts')],
                [R.T, R.always('')]
            ]));

    const onLineSelected = (selectedLines) => {
        const {
            model,
            selectedAction: originalSelectedAction,
            selectedLines: originalSelectedLines
        } = props;
        const editableSection = R.pipe(
            splitLines,
            R.nth(getLineNumber(selectedLines))
        )(model);
        const selectedAction = !R.equals(selectedLines, originalSelectedLines) ? 'replace' : originalSelectedAction;
        const selectedPath = getSelectedPath(selectedLines);
        updateField({
            editableSection,
            selectedAction,
            selectedLines,
            selectedPath
        });
    };

    const onModelChange = (editableSection) => updateField({
        editableSection,
        pristine: false
    });

    const onModifyingPatch = () => selectAction('replace');

    const onRemovingPatch = () => selectAction('remove');

    const {
        editableSection,
        filePath,
        fileType,
        model,
        pristine,
        selectedAction,
        selectedLines,
        selectedPath
    } = props;

    return <XlReactWidgetPatchEditor
        description={localeMessages.patchEditorDescription}
        editableSection={editableSection}
        filePath={filePath}
        handleEditableSelectionChange={onModelChange}
        handleLineSelected={onLineSelected}
        handleModifyingPatch={onModifyingPatch}
        handleRemovingPatch={onRemovingPatch}
        model={model}
        onPushPatchChange={handlePushPatchChange}
        pristine={pristine}
        selectedAction={selectedAction}
        selectedLines={selectedLines}
        selectedPath={selectedPath}
        type={fileType}
    />;
};

WidgetPatchTestEditor.propTypes = {
    currentState: PropTypes.object,
    editableSection: PropTypes.string.isRequired,
    filePath: PropTypes.string.isRequired,
    fileType: PropTypes.string.isRequired,
    model: PropTypes.string.isRequired,
    modelName: PropTypes.string,
    pristine: PropTypes.bool.isRequired,
    selectedAction: PropTypes.string.isRequired,
    selectedLines: PropTypes.arrayOf(PropTypes.string).isRequired,
    selectedPath: PropTypes.string.isRequired,
    updateState: PropTypes.func
};

export default React.memo(WidgetPatchTestEditor);
